@@ -12,22 +12,28 @@ class HttpClient:
         self.logger = logging.getLogger(etools.consts.LOGGER_NAME)
 
     def get(self, url, headers=None, timeout=5, timeout_retry=3,
-            decode_json=True, **kwargs):
+            decode_json=True, return_binary=False, **kwargs):
         return self.request("get", url, None, headers, None,
-                            timeout, timeout_retry, decode_json, **kwargs)
+                            timeout, timeout_retry, decode_json,
+                            return_binary, **kwargs)
 
     def post(self, url, data, headers=None,
-             timeout=5, timeout_retry=3, decode_json=True, **kwargs):
+             timeout=5, timeout_retry=3, decode_json=True,
+             return_binary=False, **kwargs):
         return self.request("post", url, data, headers, None,
-                            timeout, timeout_retry, decode_json, **kwargs)
+                            timeout, timeout_retry, decode_json,
+                            return_binary, **kwargs)
 
     def post_form(self, url, data, files, headers=None,
-                        timeout=5, timeout_retry=3, decode_json=True, **kwargs):
+                        timeout=5, timeout_retry=3, decode_json=True,
+                        return_binary=False, **kwargs):
         return self.request("post", url, data, headers, files,
-                            timeout, timeout_retry, decode_json, **kwargs)
+                            timeout, timeout_retry, decode_json,
+                            return_binary, **kwargs)
 
     def request(self, method, url, data, headers=None, files=None,
-                timeout=5, timeout_retry=3, decode_json=True, **kwargs):
+                timeout=5, timeout_retry=3, decode_json=True,
+                return_binary=False, **kwargs):
         for _ in range(timeout_retry):
             fileobjs = []
             try:
@@ -44,9 +50,12 @@ class HttpClient:
                         " code[%d], response[%s]",
                         method, url, data, headers, kwargs, resp.status_code, resp.text)
                     return None
-                result = resp.content.decode("utf8")
-                if decode_json:
-                    result = json.loads(result)
+                if return_binary:
+                    result = resp.content
+                else:
+                    result = resp.content.decode("utf8")
+                    if decode_json:
+                        result = json.loads(result)
                 return result
             except Timeout as e:
                 self.logger.warning(
